@@ -28,12 +28,14 @@
 #ifndef __KGAMEDIALOG_H__
 #define __KGAMEDIALOG_H__
 
-#include <kpagedialog.h>
-#include <QVBoxLayout>
+#include <KPageDialog>
+
 #include <QGridLayout>
+#include <QVBoxLayout>
+
 class QGridLayout;
 class QVBoxLayout;
-class KVBox;
+
 
 class KGame;
 class KPlayer;
@@ -87,7 +89,7 @@ public:
 	 * @param g The KGame object of this game
 	 * @param owner The KPlayer object who is responsible for this
 	 * dialog, aka "the local player"
-	 * @param title The title of the dialog - see KDialog::setCaption
+	 * @param title The title of the dialog - see QDialog::setWindowTitle
 	 * @param parent The parent of the dialog
 	 * @param modal Whether the dialog is modal or not
 	 * @param initConfigs whether the default KGameDialogConfig widgets
@@ -143,13 +145,13 @@ public:
 	 * @param title The title of the newly added page.
 	 * @return The newly added page which contains your config widget.
 	 **/
-	KVBox* addConfigPage(KGameDialogConfig* widget, const QString& title);
+	QWidget * addConfigPage(KGameDialogConfig* widget, const QString& title);
 
 	/**
 	 * @return The QVBox of the given key, The key is from ConfigOptions
 	 * Note that not all are supported yet
 	 **/
-	KVBox *configPage();
+	QWidget *configPage();
 
 	/**
 	 * @return The default netowrk config. Note that this always returns 0 if
